pub struct ParseConfig {
    pub allow_from_stdin: bool,
    pub allow_to_stdout: bool,
    pub auto_tnamed_dst_file: bool,
    pub auto_tnamed_dst_dir: bool,
    pub default_extension: OsString,
    pub allow_inplace: bool,
}
Use single hyphen (-) as path to indicate IO from Stdio.

Notes

  • Auto time-based unique naming (auto_tnamed_dst_) only takes effect when DST is not provided.

Fields

allow_from_stdin: boolallow_to_stdout: boolauto_tnamed_dst_file: boolauto_tnamed_dst_dir: booldefault_extension: OsStringallow_inplace: bool

Disallowed by default. There may be a potential to open and create the same file at the same time.

Implementations

source

impl ParseConfig

source

pub fn new<S: AsRef<OsStr>>(default_extension: S) -> Self

source

pub fn new_with_allow_inplace<S: AsRef<OsStr>>(default_extension: S) -> Self

source

pub fn parse<P: AsRef<Path>>( &self, src: P, dst: Option<P> ) -> Result<Result<IoPairs, ParseError>>

Possible Combinations
SRC => DST:   Stdout,6   File   Dir     NotProvided
Stdin,6          1+2      1      1         1+3,5
File               2      ✓      ✓           3
Dir                ×      ×      ✓           4
  1. allow_from_stdin.
  2. allow_to_stdout.
  3. auto_tnamed_dst_file.
  4. auto_tnamed_dst_dir. Note: A directory with specified name will not be created automatically (an error will be returned if it does not exist).
  5. Note that std::env::current_dir will be used as output directory.
  6. Stdio will be always treated as a file.