Struct src_dst_clarifier::ParseConfig
source · pub struct ParseConfig {
pub allow_from_stdin: bool,
pub allow_to_stdout: bool,
pub auto_tnamed_dst_file: bool,
pub auto_tnamed_dst_dir: bool,
pub default_extension: OsString,
pub allow_inplace: bool,
}Expand description
Use single hyphen (-) as path to indicate IO from Stdio.
Notes
- Auto time-based unique naming (
auto_tnamed_dst_) only takes effect when DST is not provided.
Fields
allow_from_stdin: boolallow_to_stdout: boolauto_tnamed_dst_file: boolauto_tnamed_dst_dir: booldefault_extension: OsStringallow_inplace: boolDisallowed by default. There may be a potential to open and create the same file at the same time.
Implementations
sourceimpl ParseConfig
impl ParseConfig
pub fn new<S: AsRef<OsStr>>(default_extension: S) -> Self
pub fn new_with_allow_inplace<S: AsRef<OsStr>>(default_extension: S) -> Self
sourcepub fn parse<P: AsRef<Path>>(
&self,
src: P,
dst: Option<P>
) -> Result<Result<IoPairs, ParseError>>
pub fn parse<P: AsRef<Path>>( &self, src: P, dst: Option<P> ) -> Result<Result<IoPairs, ParseError>>
Possible Combinations
SRC => DST: Stdout,6 File Dir NotProvided
Stdin,6 1+2 1 1 1+3,5
File 2 ✓ ✓ 3
Dir × × ✓ 4
allow_from_stdin.allow_to_stdout.auto_tnamed_dst_file.auto_tnamed_dst_dir. Note: A directory with specified name will not be created automatically (an error will be returned if it does not exist).- Note that
std::env::current_dirwill be used as output directory. - Stdio will be always treated as a file.